@@ -1,9 +1,9 @@
-import sys
 import csv
 from datetime import datetime
 
 from ofxstatement.statement import Statement, StatementLine
 
+
 class StatementParser(object):
     """Abstract statement parser.
 
@@ -17,6 +17,8 @@ class StatementParser(object):
         """Read and parse statement
 
         Return Statement object
+
+        May raise exceptions.ParseException on malformed input.
         """
         reader = self.split_records()
         for line in reader:
@@ -24,7 +26,8 @@ class StatementParser(object):
             if not line:
                 continue
             stmt_line = self.parse_record(line)
-            if (stmt_line):
+            if stmt_line:
+                stmt_line.assert_valid()
                 self.statement.lines.append(stmt_line)
         return self.statement
 
@@ -74,7 +77,7 @@ class CsvStatementParser(StatementParser):
         stmt_line = StatementLine()
         for field, col in self.mappings.items():
             if col >= len(line):
-                raise ValueError("Cannot find column %s in line of %s items " \
+                raise ValueError("Cannot find column %s in line of %s items "
                                  % (col, len(line)))
             rawvalue = line[col]
             value = self.parse_value(rawvalue, field)
