@@ -20,15 +20,20 @@ def get_version():
 
 def configure_logging(args):
     format = '%(levelname)s: %(message)s'
-    logging.basicConfig(format=format, level=logging.INFO)
+    arg_level = logging.DEBUG if args.debug else logging.INFO
+    logging.basicConfig(format=format, level=arg_level)
 
 
 def make_args_parser():
     parser = argparse.ArgumentParser(
-        description='Tool to convert proprietary bank statement to OFX format.')
+        description='Tool to convert proprietary bank statement ' +
+        'to OFX format.')
     parser.add_argument("--version", action="version",
                         version='%%(prog)s %s' % get_version(),
                         help="show current version")
+    parser.add_argument("-d", "--debug", action="store_true",
+                        default=False,
+                        help="show debugging information")
 
     subparsers = parser.add_subparsers(title="action")
 
